==> payara-embedded-all-4.1.1.171-sources.jar: org/glassfish/admin/cli/resources/UniqueResourceNameValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.cli.resources;

import com.sun.enterprise.config.serverbeans.Domain;
import com.sun.enterprise.config.serverbeans.Resource;

import org.glassfish.hk2.api.ServiceLocator;
import org.glassfish.internal.api.Globals;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * Created with IntelliJ IDEA.
 * User: naman
 * Date: 2/8/12
 * Time: 4:11 PM
 * To change this template use File | Settings | File Templates.
 */
public class UniqueResourceNameValidator implements ConstraintValidator<UniqueResourceNameConstraint, Resource> {

    Domain domain = null;

    public void initialize(final UniqueResourceNameConstraint constraint) {

        /*ServiceLocator locator = ServiceLocatorFactory.getInstance().find("default");
        if (locator == null) return;

        ConfigBeansUtilities cbu = locator.getService(ConfigBeansUtilities.class);
        if (cbu == null) return;

        domain = cbu.getDomain();*/

        ServiceLocator habitat = Globals.getDefaultHabitat();
        if (habitat == null) return; // due to: http://java.net/jira/browse/GLASSFISH-19043

        domain = habitat.getService(Domain.class);

    }

    @Override
    public boolean isValid(final Resource resource,
                           final ConstraintValidatorContext constraintValidatorContext) {
        if (domain != null) {
            if (resource.getParent().getParent() instanceof Domain) {
                for (Resource res : domain.getResources().getResources()) {
                    if (resource.getIdentity().equals(res.getIdentity())) {
                        Class[] resourceInterfaces = resource.getClass().getInterfaces();
                        Class[] resInterfaces = res.getClass().getInterfaces();

                        for (Class resourceClass : resourceInterfaces) {
                            for (Class resClass : resInterfaces) {
                                if (resClass.getName().equals(resourceClass.getName())) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                }
            }
        }
        return true;
    }
}

==> payara-embedded-all-5.201-sources.jar: org/glassfish/admin/cli/resources/UniqueResourceNameValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018] Payara Foundation and/or affiliates

package org.glassfish.admin.cli.resources;

import com.sun.enterprise.config.serverbeans.Domain;
import com.sun.enterprise.config.serverbeans.Resource;

import org.glassfish.hk2.api.ServiceLocator;
import org.glassfish.internal.api.Globals;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * 
 * @author naman
 * @since 4.0
 */
public class UniqueResourceNameValidator implements ConstraintValidator<UniqueResourceNameConstraint, Resource> {

    Domain domain = null;

    @Override
    public void initialize(final UniqueResourceNameConstraint constraint) {

        ServiceLocator habitat = Globals.getDefaultHabitat();
        if (habitat == null) return; // due to: http://java.net/jira/browse/GLASSFISH-19043

        domain = habitat.getService(Domain.class);

    }

    @Override
    public boolean isValid(final Resource resource,
                           final ConstraintValidatorContext constraintValidatorContext) {
        if (domain != null) {
            if (resource.getParent().getParent() instanceof Domain) {
                for (Resource res : domain.getResources().getResources()) {
                    if (resource.getIdentity().equals(res.getIdentity())) {
                        Class[] resourceInterfaces = resource.getClass().getInterfaces();
                        Class[] resInterfaces = res.getClass().getInterfaces();

                        for (Class resourceClass : resourceInterfaces) {
                            for (Class resClass : resInterfaces) {
                                if (resClass.isAssignableFrom(resourceClass)) {
                                    return true;
                                }
                            }
                        }
                        return false;
                    }
                }
            }
        }
        return true;
    }
}
